@@ -1,12 +1,12 @@
 #!/usr/bin/python
 
-from gi.repository import Gtk, Gst, GObject 
+from gi.repository import Gtk, Gst, GObject
 import os, sys
 
 #Comment the first line and uncomment the second before installing
 #or making the tarball (alternatively, use project variables)
-UI_FILE = "src/guitar_tuner_py.ui"
-#UI_FILE = "/usr/local/share/guitar_tuner_py/ui/guitar_tuner_py.ui"
+UI_FILE = "src/guitar_tuner.ui"
+#UI_FILE = "/usr/local/share/guitar_tuner_py/ui/guitar_tuner.ui"
 
 class GUI:
 	LENGTH = 500
@@ -19,7 +19,7 @@ class GUI:
 		'B': 987.77,
 		'e': 1318.5
 	}
-	
+
 	def __init__(self):
 		self.builder = Gtk.Builder()
 		self.builder.add_from_file(UI_FILE)
@@ -44,22 +44,21 @@ class GUI:
 		pipeline = Gst.Pipeline(name='note')
 		source = Gst.ElementFactory.make('audiotestsrc', 'src')
 		sink = Gst.ElementFactory.make('autoaudiosink', 'output')
-		
+
 		source.set_property('freq', frequency)
 		pipeline.add(source)
 		pipeline.add(sink)
-
-		source.link (sink)
+		source.link(sink)
 
 		pipeline.set_state(Gst.State.PLAYING)
 
 		GObject.timeout_add(self.LENGTH, self.pipeline_stop, pipeline)
-		
+
 def main():
 	Gst.init_check(sys.argv)
 	app = GUI()
 	Gtk.main()
-		
+
 if __name__ == "__main__":
     sys.exit(main())
 
